models

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 11, 2021 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

const (
	TemplatesDir = "pkg/templates"
	Helm         = "helm"
)

Variables

var (
	TiltTemplatePath = fmt.Sprintf("%s/tilt.tmpl", TemplatesDir)
)

Functions

This section is empty.

Types

type Deployment

type Deployment struct {
	Name string `json:"name" yaml:"name"`
	File string `json:"file" yaml:"file"`
}

Deployment represents configuration options for the helm deployment spec.

type HelmLocalDeployment

type HelmLocalDeployment struct {
	Name string `json:"name" yaml:"name"`
	Dir  string `json:"dir" yaml:"dir"`
}

HelmLocalDeployment represents configuration options for the helm deployment spec.

type HelmRemoteDeployment

type HelmRemoteDeployment struct {
	Name            string   `json:"name" yaml:"name"`
	ReleaseName     string   `json:"release_name" yaml:"release_name"`
	RepoName        string   `json:"repo_name" yaml:"repo_name"`
	RepoURL         string   `json:"repo_url" yaml:"repo_url"`
	Version         string   `json:"version" yaml:"version"`
	Namespace       string   `json:"namespace" yaml:"namespace"`
	CreateNamespace string   `json:"create_namespace" yaml:"create_namespace"`
	Set             []string `json:"set" yaml:"set"`
}

HelmRemoteDeployment represents configuration options for the helm deployment spec.

type KustomizeDeployment

type KustomizeDeployment struct {
	Name string `json:"name" yaml:"name"`
	Dir  string `json:"dir" yaml:"dir"`
}

KustomizeDeployment represents configuration options for the helm Kustomizedeployment spec.

type Resource

type Resource interface {
	GetMetaData() ResourceMeta
}

Resource is a set of common actions performed on Resource Types.

type ResourceMeta

type ResourceMeta struct {
	Config       interface{}
	TemplatePath string
}

ResourceMeta contains metadata for preparing resource manifests.

type Workload

type Workload struct {
	Deployments           []Deployment           `json:"deployment" yaml:"deployment"`
	KustomizeDeployments  []KustomizeDeployment  `json:"kustomize_deployments" yaml:"kustomize_deployments"`
	HelmLocalDeployments  []HelmLocalDeployment  `json:"helm_local_deployments" yaml:"helm_local_deployments"`
	HelmRemoteDeployments []HelmRemoteDeployment `json:"helm_remote_deployments" yaml:"helm_remote_deployments"`
}

Workload represents the structure to represent all configs and resources to deploy an application.

func NewWorkload

func NewWorkload() Workload

func (Workload) GetMetaData

func (w Workload) GetMetaData() ResourceMeta

Directories

Path Synopsis

Jump to